@@ -53,7 +53,7 @@ def put_delta(S, K, T, r, sigma):
     return -1 * (np.exp(-r * T) * norm.cdf(d1(S, K, T, r, sigma)) - 1)
 
 
-def find_delta(optiontype: str, K, T, r, sigma):
+def find_delta(optiontype: str, S, K, T, r, sigma):
     if optiontype == "C":
         return call_delta(S, K, T, r, sigma)
     elif optiontype == "P":
@@ -62,7 +62,7 @@ def find_delta(optiontype: str, K, T, r, sigma):
         raise ValueError("Option type must be either C or P")
 
 
-def find_premium(optiontype: str, K, T, r, sigma):
+def find_premium(optiontype: str, S, K, T, r, sigma):
     if optiontype == "C":
         return bs_call(S, K, T, r, sigma)
     elif optiontype == "P":
@@ -71,11 +71,11 @@ def find_premium(optiontype: str, K, T, r, sigma):
         raise ValueError("Option type must be either C or P")
 
 
-def find_strike(optiontype: str, S, T, r, sigma, d):
+def find_strike(optiontype: str, S, T, r, sigma, delta):
     if optiontype == "C":
-        return find_strike_call(S, T, r, sigma, d)
+        return find_strike_call(S, T, r, sigma, delta)
     elif optiontype == "P":
-        return find_strike_put(S, T, r, sigma, d)
+        return find_strike_put(S, T, r, sigma, delta)
     else:
         raise ValueError("Option type must be either C or P")
 
@@ -99,7 +99,7 @@ class Surface:
             desc = f"{self.symbol} {self.putCall} \n Date: {self.day} \n dte: {dte}"
             curve = Curve(
                 temp.markIv.values,
-                temp.delta.values,
+                temp.delta.values if self.putCall == "C" else -temp.delta.values,
                 temp.dte,
                 temp.strike.values,
                 self.putCall,
@@ -189,6 +189,7 @@ class Curve:
         assert 0 < delta <= 0.5
         lowestIv = lowestDelta = highestIv = highestDelta = 0
         for idx in range(len(self.markIvs)):
+            print(self.deltas, self.markIvs)
             if delta < self.deltas[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestDelta = self.deltas[idx]
@@ -214,7 +215,6 @@ class Curve:
         # Reverse the strikes if call.
         should_reverse = -1 if self.putCall == "C" else 1
         for idx in range(len(self.strikes))[::should_reverse]:
-            print(idx)
             if strike < self.strikes[idx]:
                 lowestIv = self.markIvs[idx]
                 lowestStrike = self.strikes[idx]
